@@ -1,7 +1,7 @@
 package Perinci::Examples::CLI;
 
-our $DATE = '2015-09-26'; # DATE
-our $VERSION = '0.60'; # VERSION
+our $DATE = '2015-09-29'; # DATE
+our $VERSION = '0.61'; # VERSION
 
 use 5.010001;
 use strict;
@@ -323,7 +323,7 @@ Perinci::Examples::CLI - Example for CLI help/usage generation
 
 =head1 VERSION
 
-This document describes version 0.60 of Perinci::Examples::CLI (from Perl distribution Perinci-Examples), released on 2015-09-26.
+This document describes version 0.61 of Perinci::Examples::CLI (from Perl distribution Perinci-Examples), released on 2015-09-29.
 
 =head1 SEE ALSO
 
@@ -408,11 +408,11 @@ Result:
    {
      logs => [
                {
-                 file    => "/home/u1/perl5/perlbrew/perls/perl-5.22.0/lib/site_perl/5.22.0/Perinci/Access/Schemeless.pm",
+                 file    => "/home/s1/perl5/perlbrew/perls/perl-5.22.0/lib/site_perl/5.22.0/Perinci/Access/Schemeless.pm",
                  func    => "Perinci::Access::Schemeless::action_call",
                  line    => 477,
                  package => "Perinci::Access::Schemeless",
-                 time    => 1443258017,
+                 time    => 1443534299,
                  type    => "create",
                },
              ],
@@ -429,6 +429,8 @@ assumed to be marked up in I<Markdown> (currently referring to CommonMark).
 
  This paragraph should be set in verbatim.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -570,6 +572,8 @@ Examples:
 Summary for an example.
 
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
