@@ -1,10 +1,25 @@
 package Perinci::Examples::Tiny::Args;
 
-our $DATE = '2015-09-26'; # DATE
-our $VERSION = '0.60'; # VERSION
+our $DATE = '2015-09-29'; # DATE
+our $VERSION = '0.61'; # VERSION
 
 our %SPEC;
 
+# this Rinci metadata is already normalized
+$SPEC{as_is} = {
+    v => 1.1,
+    summary => "This function returns the argument as-is",
+    args => {
+        'arg' => {
+            schema => ['any',{},{}],
+        },
+    },
+};
+sub as_is {
+    my %args = @_;
+    [200, "OK", $args{arg}];
+}
+
 # this Rinci metadata is already normalized
 $SPEC{has_dot_args} = {
     v => 1.1,
@@ -66,7 +81,7 @@ Perinci::Examples::Tiny::Args - Tests related to function arguments
 
 =head1 VERSION
 
-This document describes version 0.60 of Perinci::Examples::Tiny::Args (from Perl distribution Perinci-Examples), released on 2015-09-26.
+This document describes version 0.61 of Perinci::Examples::Tiny::Args (from Perl distribution Perinci-Examples), released on 2015-09-29.
 
 =head1 DESCRIPTION
 
@@ -77,10 +92,38 @@ Perinci::CmdLine frameworks.
 =head1 FUNCTIONS
 
 
+=head2 as_is(%args) -> [status, msg, result, meta]
+
+This function returns the argument as-is.
+
+This function is not exported by default, but exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<arg> => I<any>
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
 =head2 has_date_arg(%args) -> [status, msg, result, meta]
 
 This function contains a date argument.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -105,6 +148,8 @@ Return value:  (any)
 
 This function contains arguments with dot in their names.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
